@@ -15,7 +15,7 @@ from pmb.config.merge_with_args import merge_with_args
 #
 # Exported variables (internal configuration)
 #
-version = "1.35.0"
+version = "1.36.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 
@@ -24,10 +24,10 @@ apk_keys_path = pmb_src + "/pmb/data/keys"
 # Update this frequently to prevent a MITM attack with an outdated version
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
-apk_tools_min_version = {"edge": "2.12.5-r1",
-                         "v3.14": "2.12.5-r1",
-                         "v3.13": "2.12.5-r0",
-                         "v3.12": "2.10.6-r0"}
+apk_tools_min_version = {"edge": "2.12.7-r0",
+                         "v3.14": "2.12.7-r0",
+                         "v3.13": "2.12.7-r0",
+                         "v3.12": "2.10.8-r0"}
 
 # postmarketOS aports compatibility (checked against "version" in pmaports.cfg)
 pmaports_min_version = "7"
@@ -123,6 +123,21 @@ is_interactive = sys.stdout.isatty() and \
     sys.stdin.isatty()
 
 
+# ANSI escape codes to highlight stdout
+styles = {
+    "BLUE": '\033[94m',
+    "BOLD": '\033[1m',
+    "GREEN": '\033[92m',
+    "RED": '\033[91m',
+    "YELLOW": '\033[93m',
+    "END": '\033[0m'
+}
+
+if "NO_COLOR" in os.environ:
+    for style in styles.keys():
+        styles[style] = ""
+
+
 # List of available locales taken from musl-locales package; see
 # https://pkgs.alpinelinux.org/contents?name=musl-locales
 locales = [
@@ -455,6 +470,7 @@ necessary_kconfig_options_zram = {
             "ZRAM_MEMORY_TRACKING": True,
             "CRYPTO_LZ4": True,
             "LZ4_COMPRESS": True,
+            "SWAP": True,
         }
     },
 }
