@@ -10,16 +10,23 @@ def variables(args, flavor, method):
     flash_pagesize = args.deviceinfo['flash_pagesize']
 
     if method.startswith("fastboot"):
-        _partition_kernel = args.deviceinfo["flash_fastboot_partition_kernel"] or "boot"
-        _partition_system = args.deviceinfo["flash_fastboot_partition_system"] or "system"
-        _partition_vbmeta = args.deviceinfo["flash_fastboot_partition_vbmeta"] or None
+        _partition_kernel = args.deviceinfo["flash_fastboot_partition_kernel"]\
+            or "boot"
+        _partition_system = args.deviceinfo["flash_fastboot_partition_system"]\
+            or "system"
+        _partition_vbmeta = args.deviceinfo["flash_fastboot_partition_vbmeta"]\
+            or None
     else:
-        _partition_kernel = args.deviceinfo["flash_heimdall_partition_kernel"] or "KERNEL"
-        _partition_system = args.deviceinfo["flash_heimdall_partition_system"] or "SYSTEM"
-        _partition_vbmeta = args.deviceinfo["flash_heimdall_partition_vbmeta"] or None
+        _partition_kernel = args.deviceinfo["flash_heimdall_partition_kernel"]\
+            or "KERNEL"
+        _partition_system = args.deviceinfo["flash_heimdall_partition_system"]\
+            or "SYSTEM"
+        _partition_vbmeta = args.deviceinfo["flash_heimdall_partition_vbmeta"]\
+            or None
 
     if "partition" in args and args.partition:
-        # Only one of operations is done at same time so it doesn't matter sharing the arg
+        # Only one of operations is done at same time so it doesn't matter
+        # sharing the arg
         _partition_kernel = args.partition
         _partition_system = args.partition
         _partition_vbmeta = args.partition
@@ -37,7 +44,8 @@ def variables(args, flavor, method):
         "$IMAGE": "/home/pmos/rootfs/" + args.device + ".img",
         "$KERNEL_CMDLINE": _cmdline,
         "$PARTITION_KERNEL": _partition_kernel,
-        "$PARTITION_INITFS": args.deviceinfo["flash_heimdall_partition_initfs"] or "RECOVERY",
+        "$PARTITION_INITFS": args.deviceinfo[
+            "flash_heimdall_partition_initfs"] or "RECOVERY",
         "$PARTITION_SYSTEM": _partition_system,
         "$PARTITION_VBMETA": _partition_vbmeta,
         "$FLASH_PAGESIZE": flash_pagesize,
