@@ -776,9 +776,9 @@ def install_on_device_installer(args, step, steps):
 
     # Generate installer image
     size_reserve = round(os.path.getsize(img_path_dest) / 1024 / 1024) + 200
-    boot_label = "pmOS_inst_boot"
-    if pmb.parse.version.compare(get_ondev_pkgver(args), "0.4.0") == -1:
-        boot_label = "pmOS_boot"
+    pmaports_cfg = pmb.config.pmaports.read_config(args)
+    boot_label = pmaports_cfg.get("supported_install_boot_label",
+                                  "pmOS_inst_boot")
     install_system_image(args, size_reserve, suffix_installer, step, steps,
                          boot_label, "pmOS_install", args.split, args.sdcard)
 
